--------------------------------------------------------------------------------
--
-- Title       : Scanner FPGA
-- Design      : Clock Rise Devider
-- Author      : Alex Shtengel
-- Company     : Lumenis
--------------------------------------------------------------------------------
-- File        : ClockRiseDevider.vhd
-- Generated   : Mar 15  2015
--------------------------------------------------------------------------------
-- Description : Devide clock with sync by main clock, output clock pulse rise
--------------------------------------------------------------------------------
-- Revision History :
-- -----------------------------------------------------------------------------
--   Ver  :| Author            :| Mod. Date :|    Changes Made:
--   v1.0  | Alex Shtengel	   :| 15/03/15	:| Automatically Generated
-- -----------------------------------------------------------------------------
library ieee;
use 		ieee.std_logic_1164.all;

entity ClockRiseDevider is
GENERIC (DivideRange	: integer);
port
(
 ClockIn ,      		-- General Clock
 nResetIn,					-- General Reset active low
 ClockRiseIn        -- Clock for divide by Divide Range
 									: in std_logic;
 ClockRiseOut       -- OutPut clock
 									: out 	std_logic
);
end ClockRiseDevider;

architecture ArchClockRiseDevider of ClockRiseDevider is

signal ClockTmp   	-- Temporary clock signals for make rise signal
									: std_logic_vector(1 downto 0) := "00";
signal ClockDivider 	,
			 DividerFactor
			 						: integer range 0 to DivideRange;
begin
DividerFactor <= DivideRange - 1;
DivideProcess_Process:
process (ClockIn)
begin
 if(ClockIn'event and ClockIn = '1') then
	case nResetIn is
	 when '0' =>
 		ClockDivider <= 0;
 		ClockTmp			<= (others => '0');
		ClockRiseOut	<= '0';
	 when others =>
		if (ClockRiseIn = '1') then
		 if (ClockDivider = DividerFactor) then
		   ClockDivider <= 0;
			 ClockTmp(0)	<= '1' ;  -- Clock signal after divide ClockRiseIn to Divide Range
		  else
		   ClockDivider <= ClockDivider + 1 mod DividerFactor;
		 	ClockTmp(0)	<= '0' ;
		 end if;
		else
		 ClockDivider <= ClockDivider ;
		 ClockTmp(0)	<= ClockTmp(0) ;
		end if ;
		ClockTmp(1)	<= ClockTmp(0);											--
		ClockRiseOut	<= not ClockTmp(1) and ClockTmp(0);	-- OutPut clock
	end case;
 end if;
end process  DivideProcess_Process;


end ArchClockRiseDevider;
