--------------------------------------------------------------------------------
--
-- Title       : Uart
-- Design      : Uart Main
-- Author      : Alex Shtengel
-- Company     : Home
--------------------------------------------------------------------------------
-- File        : UartMain.vhd
-- Generated   : Feb 10  2009
--------------------------------------------------------------------------------
-- Description : Uart RS232/422 ,1 Start Bit, 1 Stop bit , not parity bit
--------------------------------------------------------------------------------
-- Revision History :
-- -----------------------------------------------------------------------------
--   Ver  :| Author            :| Mod. Date :|    Changes Made:
--   v1.0  | Alex Shtengel	   :| 10/02/09	:| Automatically Generated
-- -----------------------------------------------------------------------------
library ieee ;

use ieee.std_logic_1164.all ;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;

entity UartMain  is
GENERIC (BaudRate : integer := 5);         																		 -- BaudRate
																					 																			-- 5 921.600  for General Clock 73.728 MHz
																					 																			-- 4 115.200
																					 																			-- 3  57.600
																					 																			-- 2  38.400
																					 																			-- 1  19.200
																					 																			-- 0   9.600
port
(
 ClockIn ,        												 																			-- General Clock 18.432 MHz
 nResetIn ,         											 																			-- General Reset active High
 nReadIn,            											 																			-- Read Received Data active 0
 nWriteIn,            										 																			-- Write data for transmit
 SerialDataIn             								 																			-- Serial data from line
                    : in std_logic;
 TransmitDataIn             							 																			-- Data for transmit
                    : in std_logic_vector(7 downto 0);
 nRxReadyOut,            									 																			-- Received Data Ready active 0
 nTxReadyOut,            									 																			-- Transmit Ready active 0
 SerialDataOut             								 																			-- Serial data for Transmit
                    : out std_logic;
 ReceiveDataOut             							 																			-- Received Data
                    : out std_logic_vector(7 downto 0)
);
end UartMain;

architecture  ArchUartMain of UartMain is

signal Clock_921_600,                      																			-- Basick Clock x 16 for 921.600
			 Clock_115_200,                      																			-- Basick Clock x 16 for 115.200
			 Clock_57_600,                       																			-- Basick Clock x 16 for  57.600
			 Clock_38_400,                       																			-- Basick Clock x 16 for  38.400
			 Clock_19_200,                       																			-- Basick Clock x 16 for  19.200
			 Clock_9_600,                        																			-- Basick Clock x 16 for   9.600
			 BasicP16Clock                       																		 	-- Basic  Clock x 16
										: std_logic := '0';
signal Baud_Rate : integer range 0 to 5 := 5 ;

begin

Baud_Rate     <= BaudRate;

 Clock_921_600_Inst : entity	work.ClockRiseDevider
GENERIC MAP (5)
port map
(
 ClockIn 				=> ClockIn,      					 																			-- General Clock   73.728 MHz
 nResetIn				=> nResetIn,							 																			-- General Reset active High
 ClockRiseIn    => '1',    								 																			-- Clock for divide by Divide Range
 ClockRiseOut   => Clock_921_600           																		 	-- Basick Clock x 16 for 921.600
);


Clock_115_200_Inst : entity	work.ClockRiseDevider
GENERIC MAP (10)
port map
(
 ClockIn 				=> ClockIn,      					 																			-- General Clock
 nResetIn				=> nResetIn,							 																			-- General Reset active High
 ClockRiseIn    => '1',    								 																			-- Clock for divide by Divide Range
 ClockRiseOut   => Clock_115_200           																			-- Basick Clock x 16 for 115.200
);

Clock_57_600_Inst : entity	work.ClockRiseDevider
GENERIC MAP (20)
port map
(
 ClockIn 				=> ClockIn,      					 																			-- General Clock
 nResetIn				=> nResetIn,							 																			-- General Reset active High
 ClockRiseIn    => '1',    								 																			-- Clock for divide by Divide Range
 ClockRiseOut   => Clock_57_600            																			-- Basick Clock x 16 for 57.600
);

Clock_38_400_Inst : entity	work.ClockRiseDevider
GENERIC MAP (30)
port map
(
 ClockIn 				=> ClockIn,      					 																			-- General Clock
 nResetIn				=> nResetIn,							 																			-- General Reset active High
 ClockRiseIn    => '1',    								 																			-- Clock for divide by Divide Range
 ClockRiseOut   => Clock_38_400            																			-- Basick Clock x 16 for 38.400
);

Clock_19_200_Inst : entity	work.ClockRiseDevider
GENERIC MAP (600)
port map
(
 ClockIn 				=> ClockIn,      					 																			-- General Clock
 nResetIn				=> nResetIn,							 																			-- General Reset active High
 ClockRiseIn    => '1',    								 																			-- Clock for divide by Divide Range
 ClockRiseOut   => Clock_19_200            																			-- Basick Clock x 16 for 19.200
);

Clock_9_600_Inst : entity	work.ClockRiseDevider
GENERIC MAP (120)
port map
(
 ClockIn 				=> ClockIn,      					 																			-- General Clock
 nResetIn				=> nResetIn,							 																			-- General Reset active High
 ClockRiseIn    => '1',    								 																			-- Clock for divide by Divide Range
 ClockRiseOut   => Clock_9_600             																			-- Basick Clock x 16 for 9.600
);

 BasicP16Clock_Process:
process (ClockIn ,nResetIn)
begin
 if(nResetIn = '0') then
	BasicP16Clock <= '0';                     																		-- Basic  Clock x 16
 elsif (ClockIn'event and ClockIn = '1') then
	case Baud_Rate is
	 when 0 =>
		BasicP16Clock <= Clock_9_600;
	 when 1 =>
		BasicP16Clock <= Clock_19_200;
	 when 2 =>
		BasicP16Clock <= Clock_38_400;
	 when 3 =>
		BasicP16Clock <= Clock_57_600;
	 when 4 =>
		BasicP16Clock <= Clock_115_200;
	 when 5 =>
		BasicP16Clock <= Clock_921_600;
	 when others =>
		BasicP16Clock <= Clock_9_600;
	end case;
 end if;
end process  BasicP16Clock_Process;

UartTransmit_Inst : entity	work.UartTransmit
port map
(
 ClockIn 					=> ClockIn,        			 																			-- General Clock
 nResetIn 				=> nResetIn,         		 																			-- General Reset active High
 BasicP16ClockIn	=> BasicP16Clock,        																		 	-- Basic  Clock x 16
 nWriteIn         => nWriteIn,    				 																			-- Write data for transmit
 TransmitDataIn   => TransmitDataIn,       																		 	-- Data for transmit
 nTxReadyOut			=> nTxReadyOut,          																		 	-- Transmit Ready active 0
 SerialDataOut    => SerialDataOut         																			-- Serial data for Transmit
);

UartReceive_Inst : entity	work.UartReceive
port map
(
 ClockIn 						=> ClockIn,        			 																		-- General Clock
 nResetIn 					=> nResetIn,         	 																			-- General Reset active High
 BasicP16ClockIn		=> BasicP16Clock,        																	 	-- Basic  Clock x 16
 SerialDataIn				=> SerialDataIn,         																	 	-- Serial data from line
 nReadIn            => nReadIn, 						 																		-- Read Received Data active 0
 nRxReadyOut        => nRxReadyOut,     		 																		-- Received Data Ready active 0
 ReceiveDataOut     => ReceiveDataOut        																		-- Received Data
);

end ArchUartMain;