--------------------------------------------------------------------------------
--
-- Title       : Uart
-- Design      : Uart Main test bench
-- Author      : Alex Shtengel
-- Company     : Home
--------------------------------------------------------------------------------
-- File        : UartMain_Tb.vhd
-- Generated   : Feb 10  2009
--------------------------------------------------------------------------------
-- Description : Uart RS232/422 ,1 Start Bit, 1 Stop bit , not parity bit
--------------------------------------------------------------------------------
-- Revision History :
-- -----------------------------------------------------------------------------
--   Ver  :| Author            :| Mod. Date :|    Changes Made:
--   v1.0  | Alex Shtengel	   :| 10/02/09	:| Automatically Generated
-- -----------------------------------------------------------------------------
library ieee ;

use ieee.std_logic_1164.all ;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;

entity UartMain_Tb  is
end UartMain_Tb;

architecture  ArchUartMain_Tb of UartMain_Tb is
signal ClockHigh,       																 		 		 		 		 		 		-- Clock 18.432 MHz
			 ClockLow        																 		 		 		 		 		 			-- Clock 18.432 MHz
										: std_logic := '0';
signal nReset,          																												-- General Reset active Low
 			 SerialDataHigh,            								 															-- Serial data from line
 			 SerialDataLow              								 															-- Serial data from line
										: std_logic  := '0';
signal nReadLow,            											 															-- Read Received Data active 0
 			 nWriteLow,            										 																-- Write data for transmit
			 nReadHigh,            											 															-- Read Received Data active 0
 			 nWriteHigh,            										 															-- Write data for transmit
  		 nRxReadyHigh,
			 nTxReadyHigh,
	 		 nRxReadyLow,
			 nTxReadyLow
										: std_logic  := '1';

signal SerialDataHighIn,
			 SerialDataLowIn
										: std_logic := '1';

 signal TransmitDataHigh,
				TransmitDataLow,
				ReceiveDataHigh,
				ReceiveDataLow,
				ReceiveDataHighFF,
				ReceiveDataLowFF
 										: std_logic_vector(7 downto 0) := (others => '0');

begin

ClockLow <= not ClockLow after 27.129 nS;     																	-- Clock 18.432 MHz  27.129
ClockHigh 		<= not ClockHigh after 27.124 nS;     														-- Clock 18.432 MHz  27.124
nReset		<= '1','0' after 100 nS,'1' after 200 nS;         											-- General Reset active Low

SerialDataHighIn <=  transport(SerialDataLow) after 30 uS;
SerialDataLowIn <=  transport(SerialDataHigh) after 30 uS;


UartMainHigh_UUT : entity work.UartMain
GENERIC MAP(5)         																		 											-- BaudRate
																					 																			-- 5 921.600  for General Clock 73.728 MHz
																					 																			-- 4 115.200
																					 																			-- 3  57.600
																					 																			-- 2  38.400
																					 																			-- 1  19.200
																					 																			-- 0   9.600
port map
(
 ClockIn 				=> ClockHigh,        												 										-- General Clock 18.432 MHz
 nResetIn 			=> nReset,         											 												-- General Reset active High
 nReadIn 				=> nReadHigh,            											 									-- Read Received Data active 0
 nWriteIn 			=> nWriteHigh,            										 									-- Write data for transmit
 SerialDataIn 	=> SerialDataHighIn,             								 								-- Serial data from line
 TransmitDataIn => TransmitDataHigh,             							 									-- Data for transmit
 nRxReadyOut 		=> nRxReadyHigh,            									 									-- Received Data Ready active 0
 nTxReadyOut 		=> nTxReadyHigh,            									 									-- Transmit Ready active 0
 SerialDataOut 	=> SerialDataHigh,              								 								-- Serial data for Transmit
 ReceiveDataOut => ReceiveDataHigh              							 									-- Received Data
);

UartMainLow_UUT : entity work.UartMain
GENERIC MAP(5)         																		 											-- BaudRate
																					 																			-- 5 921.600  for General Clock 73.728 MHz
																					 																			-- 4 115.200
																					 																			-- 3  57.600
																					 																			-- 2  38.400
																					 																			-- 1  19.200
																					 																			-- 0   9.600
port map
(
 ClockIn 				=> ClockLow,		        												 								-- General Clock 18.432 MHz
 nResetIn 			=> nReset,         											 												-- General Reset active High
 nReadIn 				=> nReadLow,            											 									-- Read Received Data active 0
 nWriteIn 			=> nWriteLow,            										 										-- Write data for transmit
 SerialDataIn 	=> SerialDataLowIn,             								 								-- Serial data from line
 TransmitDataIn => TransmitDataLow,             							 									-- Data for transmit
 nRxReadyOut 		=> nRxReadyLow,            									 										-- Received Data Ready active 0
 nTxReadyOut 		=> nTxReadyLow,            									 										-- Transmit Ready active 0
 SerialDataOut 	=> SerialDataLow,              								 									-- Serial data for Transmit
 ReceiveDataOut => ReceiveDataLow              							 										-- Received Data
);

 TransmitProcess_H:
process
begin
TransmitDataHigh 	<= X"AA";
nWriteHigh				<= '1';            										 												-- Write data for transmit

nReadHigh					<= '1';										 																		-- Read Received Data active 0

wait for 10000 nS ;

wait until ClockHigh'event and ClockHigh = '1';
nWriteHigh				<= '0';            										 												-- Write data for transmit

wait until nTxReadyHigh'event and nTxReadyHigh = '1';

wait until ClockHigh'event and ClockHigh = '1';
nWriteHigh				<= '1';            										 												-- Write data for transmit
---------------
wait until nRxReadyHigh'event and nRxReadyHigh = '0';

wait until ClockHigh'event and ClockHigh = '1';
nReadHigh					<= '0';										 																		-- Read Received Data active 0
ReceiveDataHighFF	<= ReceiveDataHigh;

wait until nRxReadyHigh'event and nRxReadyHigh = '1';

wait until ClockHigh'event and ClockHigh = '1';
nReadHigh					<= '1';

wait for 100000 nS ;

wait until ClockHigh'event and ClockHigh = '1';
TransmitDataHigh 	<= X"55";

wait until ClockHigh'event and ClockHigh = '1';
nWriteHigh					<= '0';            										 																-- Write data for transmit

wait until nTxReadyHigh'event and nTxReadyHigh = '1';

wait until ClockHigh'event and ClockHigh = '1';
nWriteHigh					<= '1';            										 																-- Write data for transmit
---------------

wait until nRxReadyHigh'event and nRxReadyHigh = '0';
wait until ClockHigh'event and ClockHigh = '1';
nReadHigh					<= '0';
										 																		-- Read Received Data active 0
ReceiveDataHighFF	<= ReceiveDataHigh;
wait until nRxReadyHigh'event and nRxReadyHigh = '1';

wait until ClockHigh'event and ClockHigh = '1';
nReadHigh					<= '1';
-------------

wait for 100000 nS ;

wait until ClockHigh'event and ClockHigh = '1';
TransmitDataHigh 	<= X"81";

wait until ClockHigh'event and ClockHigh = '1';
nWriteHigh					<= '0';            										 																-- Write data for transmit

wait until nTxReadyHigh'event and nTxReadyHigh = '1';

wait until ClockHigh'event and ClockHigh = '1';
nWriteHigh					<= '1';            										 																-- Write data for transmit
---------------

wait until nRxReadyHigh'event and nRxReadyHigh = '0';
wait until ClockHigh'event and ClockHigh = '1';
nReadHigh					<= '0';
ReceiveDataHighFF	<= ReceiveDataHigh;
										 																		-- Read Received Data active 0
wait until nRxReadyHigh'event and nRxReadyHigh = '1';

wait until ClockHigh'event and ClockHigh = '1';
nReadHigh					<= '1';

wait;

end process  TransmitProcess_H;

 TransmitProcess_L:
process
begin
TransmitDataLow  	<= X"55";

nWriteLow					<= '1';            										 												-- Write data for transmit
nReadLow					<= '1'; 												 															-- Read Received Data active 0

wait for 10000 nS ;

wait until ClockLow'event and ClockLow = '1';
nWriteLow					<= '0';            										 																-- Write data for transmit

wait until nTxReadyLow'event and nTxReadyLow = '1';

wait until ClockLow'event and ClockLow = '1';
nWriteLow					<= '1';            										 																-- Write data for transmit
---------------

wait until nRxReadyLow'event and nRxReadyLow = '0';

wait until ClockLow'event and ClockLow = '1';
nReadLow					<= '0';										 																		-- Read Received Data active 0
ReceiveDataLowFF	<= ReceiveDataLow;

wait until nRxReadyLow'event and nRxReadyLow = '1';
wait until ClockLow'event and ClockLow = '1';
nReadLow					<= '1';

wait for 100000 nS ;

wait until ClockLow'event and ClockLow = '1';
TransmitDataLow  	<= X"AA";

wait until ClockLow'event and ClockLow = '1';
nWriteLow					<= '0';            										 																-- Write data for transmit

wait until nTxReadyLow'event and nTxReadyLow = '1';

wait until ClockLow'event and ClockLow = '1';
nWriteLow					<= '1';            										 																-- Write data for transmit
---------------

wait until nRxReadyLow'event and nRxReadyLow = '0';

wait until ClockLow'event and ClockLow = '1';
nReadLow					<= '0';										 																		-- Read Received Data active 0
ReceiveDataLowFF	<= ReceiveDataLow;
wait until nRxReadyLow'event and nRxReadyLow = '1';

wait until ClockLow'event and ClockLow = '1';
nReadLow					<= '1';


-------------

wait for 100000 nS ;

wait until ClockLow'event and ClockLow = '1';
TransmitDataLow 	<= X"41";

wait until ClockLow'event and ClockLow = '1';
nWriteLow					<= '0';            										 																-- Write data for transmit

wait until nTxReadyLow'event and nTxReadyLow = '1';

wait until ClockLow'event and ClockLow = '1';
nWriteLow					<= '1';            										 																-- Write data for transmit
---------------

wait until nRxReadyLow'event and nRxReadyLow = '0';
wait until ClockLow'event and ClockLow = '1';
nReadLow					<= '0';
ReceiveDataLowFF	<= ReceiveDataLow;
										 																		-- Read Received Data active 0
wait until nRxReadyLow'event and nRxReadyLow = '1';

wait until ClockLow'event and ClockLow = '1';
nReadLow					<= '1';

wait;

end process  TransmitProcess_L;



end ArchUartMain_Tb;
